<details>
    <summary>
        Date format
        <span id="dateformat-badge" class="badge badge-primary">{{ datetime_format_name }}</span>
    </summary>
    <ul class="max-h-64 overflow-y-scroll">
        <li
                hx-get="{% url 'htmx:dateformat-names' %}"
                hx-target="closest ul"
                hx-swap="innerHTML"
                hx-trigger="load"
        ><p>loading...</p></li>
    </ul>
</details>
