  <li>
	  HTMX-app
	  {% block incident_pk %}
	  {% include "htmx/incidents/_incident_pk.html" %}
	  {% endblock %}
	  {% block status %}
	  {% include "htmx/incidents/_incident_status.html" %}
	  {% endblock %}
	  {% block acknowledgement %}
	  {% include "htmx/incidents/_incident_ack.html" %}
	  {% endblock %}
	  {% block tag %}
	  {% include "htmx/incidents/_incident_tag.html" with tag="location" %}
	  {% endblock %}
	  {% block start_time %}
	  {% include "htmx/incidents/_incident_start_time.html" %}
	  {% endblock %}
	  {% block description %}
	  {% include "htmx/incidents/_incident_description.html" %}
	  {% endblock %}
  </li>
