{% extends "htmx/base.html" %}
{% load widget_tweaks %}

{% block main %}
<div class="p-6 flex justify-center">
  <div class="card border border-primary p-2 w-full sm:w-96 flex items-center">
    <h2 class="card-title">Log In</h2>

    <section class="card-body">
    <form method="post" class="flex flex-col gap-6">
      {% csrf_token %}
      {% for field in form %}
      <label class="flex flex-row items-center gap-2">
        <span class="w-24">{{ field.label }}:</span>
        <div class="indicator">
          <span class="indicator-item indicator-top indicator-start badge border-none mask mask-circle text-warning text-base">＊</span>
          {{ field|add_class:"input input-bordered border-accent grow" }}
        </div>
      </label>
      {% endfor %}
      <button type="submit" class="btn btn-primary">Log In</button>
    </form>
    </section>

</div>
{% endblock main %}
