{% extends 'htmx/_base_form_modal.html' %}
{% block dialogform %}
<label>Ticket url
   <input name="ticket_url" required placeholder="Ticket url" class="input input-bordered w-full max-w-xs"/>
</label>
{% endblock dialogform %}
