<!DOCTYPE html>{% load static %}
<html lang="en-US" data-theme="{{ theme }}">
<!-- argus/site/templates/base.html -->
<head>
    <meta charset="utf-8"/>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    {% block title %}<title>Argus Server: {{ page_title }}</title>{% endblock %}
    <!-- HTMX -->
    <script src="{% static "htmx-2.0.2.min.js" %}"></script>
    <link rel="stylesheet" href="{% static path_to_stylesheet|default:"styles.css" %}">

    {% block head %}
    {% endblock head %}
</head>
<body {% block body_overrides %}class="override bg-base-100"{% endblock %}>
{% block header %}
    <h1>Argus Server: {{ page_title }}</h1>
{% endblock header %}

<main class="space-y-2 p-1">
    {% block main %}
    {% endblock main %}
</main>

{% block footer %}
{% endblock footer %}

{% block tail %}{% endblock tail %}
</body>
</html>
